# eric7.MicroPython.AddEditDevicesDialog

Module implementing a dialog to add or edit data of unknown MicroPython devices.

### Global Attributes

None

### Classes

AddEditDevicesDialog | Class implementing a dialog to add or edit data of unknown MicroPython devices.

### Functions

None

## AddEditDevicesDialog

Class implementing a dialog to add or edit data of unknown MicroPython devices.

### Derived from

QDialog, Ui_AddEditDevicesDialog

### Class Attributes

None

### Class Methods

None

### Methods

AddEditDevicesDialog | Constructor
getDeviceDict | Public method to get the entered data as a dictionary.
on_deviceTypeComboBox_currentIndexChanged | Private slot to handle the selection of a device type.
on_reportButton_clicked | Private slot to report the entered data to the eric-bugs email address.

### Static Methods

None

#### AddEditDevicesDialog (Constructor)

AddEditDevicesDialog(vid=0, pid=0, description=0, deviceData=None, parent=None)

Constructor

Note: Either vid and pid and description or deviceData dictionary must be given.

vid (int (optional))
  vendor ID of the device (defaults to 0)
pid (int (optional))
  product ID of the device (defaults to 0)
description (str (optional))
  description for the device (defaults to "")
deviceData (dict (optional))
  type of the device (defaults to None)
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### AddEditDevicesDialog.getDeviceDict

getDeviceDict()

Public method to get the entered data as a dictionary.

Return:
  dictionary containing the entered data

Return Type:
  dict

#### AddEditDevicesDialog.on_deviceTypeComboBox_currentIndexChanged

on_deviceTypeComboBox_currentIndexChanged(index)

Private slot to handle the selection of a device type.

index (int)
  index of the current item

#### AddEditDevicesDialog.on_reportButton_clicked

on_reportButton_clicked()

Private slot to report the entered data to the eric-bugs email address.

Up